Security Advisories (4)
CVE-2006-4484 (2008-10-01)

Buffer overflow in the LWZReadByte_ function in the GD extension in allows remote attackers to have an unknown impact via a GIF file with input_code_size greater than MAX_LWZ_BITS, which triggers an overflow when initializing the table array.

CVE-2007-4769 (2008-01-09)

The regular expression parser in TCL before 8.4.17, as used in PostgreSQL 8.2 before 8.2.6, 8.1 before 8.1.11, 8.0 before 8.0.15, and 7.4 before 7.4.19, allows remote authenticated users to cause a denial of service (backend crash) via an out-of-bounds backref number.

CVE-2007-4772 (2008-01-09)

The regular expression parser in TCL before 8.4.17, as used in PostgreSQL 8.2 before 8.2.6, 8.1 before 8.1.11, 8.0 before 8.0.15, and 7.4 before 7.4.19, allows context-dependent attackers to cause a denial of service (infinite loop) via a crafted regular expression.

CVE-2007-6067 (2008-01-09)

Algorithmic complexity vulnerability in the regular expression parser in TCL before 8.4.17, as used in PostgreSQL 8.2 before 8.2.6, 8.1 before 8.1.11, 8.0 before 8.0.15, and 7.4 before 7.4.19, allows remote authenticated users to cause a denial of service (memory consumption) via a crafted "complex" regular expression with doubly-nested states.

NAME

Tk::LabFrame - labeled frame.

SYNOPSIS

use Tk::LabFrame;

$f = $parent->LabFrame(?-label=>text, -labelside=>where, ...?);

DESCRIPTION

LabFrame is exactly like Frame and additionaly allows to add a label to the frame.

WIDGET-OPTIONS

LabFrame supports the same options as the Frame widget.

Additional options of LabFrame are:

-label => text

The text of the label to be placed with the Frame.

-labelside => where

Where can be one of left, right, top, bottom or acrosstop. The first four work as might be expected and place the label to the left, right, above or below the frame respectively. The acrosstop creates a grooved frame around the central frame and puts the label near the northwest corner such that it appears to "overwrite" the groove.

EXAMPLE

Run the following test program to see this in action:

    use strict;
    use Tk;
    require Tk::LabFrame;
    require Tk::LabEntry;

    my $test = 'Test this';
    my $mw = Tk::MainWindow->new;
    my $f = $mw->LabFrame(-label => "This is a label",
			   -labelside => "acrosstop");
    $f->LabEntry(-label => "Testing", -textvariable => \$test)->pack;
    $f->pack;
    Tk::MainLoop;

BUGS

Perhaps LabFrame should be subsumed within the generic pTk labeled widget mechanism.

AUTHOR

Rajappa Iyer rsi@earthling.net

This code is derived from LabFrame.tcl and LabWidg.tcl in the Tix4.0 distribution by Ioi Lam. The code may be redistributed under the same terms as Perl.